//--------------------------------------------------------------
// Press F1 to get help about using script.
// To access an object that is not located in the current class, start the call with Globals.
// When using events and timers be cautious not to generate memoryleaks,
// please see the help for more information.
//---------------------------------------------------------------

/*
	*******************************************************************
	All examples in this support document are only intended
	to improve understanding of the functionality and 
	handling of the equipment. 
	Beijer Electronics AB cannot assume any liability if these
	examples are used in real applications.
	In view of the wide range of applications for this 
	equipment, users must acquire sufficient knowledge 
	themselves in order to ensure that it is correctly used in 
	their specific application. Persons responsible for the 
	application and the equipment must themselves 
	ensure that each application is in compliance with all 
	relevant requirements, standards and legislation in 
	respect to configuration and safety.
	Beijer Electronics AB will accept no liability for any 
	damage incurred during the installation or use of this 
	equipment.
	Beijer Electronics AB prohibits all modification, changes
	or conversion of the equipment.
	*******************************************************************
	*/

namespace Neo.ApplicationFramework.Generated
{
    using System.Windows.Forms;
    using System;
    using System.Drawing;
    using Neo.ApplicationFramework.Tools;
    using Neo.ApplicationFramework.Common.Graphics.Logic;
    using Neo.ApplicationFramework.Controls;
    using Neo.ApplicationFramework.Interfaces;
    
	using System.IO.Ports;    									// Used for serial com

	public partial class scmBarcode
	{
		private SerialPort port;								// Communication port object
		
		private byte[] IndataBuffer = new byte[1000];			// Indatabuffer
		private int Inbuffptr = 0;								// Pointer used to fill Indatabuffer

		private string PanelSerialPort = "COM1";
		private string PCSerialPort = "COM9";
		
		/// <summary>
		/// This method sets up all communication when the script module gets created
		/// </summary>
		/// <param name="sender"></param>
		/// <param name="e"></param>
		/// <returns></returns>
		void scmBarcode_Created(System.Object sender, System.EventArgs e)
		{
			string serialport = PanelSerialPort;					// Default serial port (on panel)
			if(Environment.OSVersion.Platform != PlatformID.WinCE)
				serialport = PCSerialPort;							// Serial port (on PC)
			port = new SerialPort(serialport, 9600, Parity.None, 8, StopBits.One);		// Set com port params here	
			port.DataReceived += new SerialDataReceivedEventHandler(comPort_DataReceived);
			port.Open();
			Globals.Tags.BarCodeString.Value = "Scan barcode";
		}		
		
		/// <summary>
		/// This metod is triggered when data is availible on the serial port, it handles
		/// recieving characters and adding them to the inbufffer. 
		/// </summary>
		/// <param name="sender"></param>
		/// <param name="e"></param>
		/// <returns></returns>
		private	void comPort_DataReceived(object sender, SerialDataReceivedEventArgs e)
		{
			//retrieve number of bytes in the buffer
			int bytes = port.BytesToRead;			
			byte c = 0;
			
			//create a byte array to hold the awaiting data
			byte[] comBuffer = new byte[bytes+100];
			
			//read the data and store it
			port.Read(comBuffer, 0, bytes);
			
			//Copy the data to the indata buffer
			for(int i=0;i<bytes;i++)
			{
				c = comBuffer[i];					
				if (c==13)									// If this is a termination character
				{
					Globals.Tags.BarCodeString.Value = System.Text.Encoding.Default.GetString(IndataBuffer,0,Inbuffptr);
					Globals.Tags.BarCodeRecieved.SetTag();
					Inbuffptr=0;							// Reset buffer pointer, throw all data
				}
				else                              			// No termination character is found 
				{		
					if(c>32)								// Strip command characters and spaces
					{
						if(Inbuffptr<IndataBuffer.Length)	// If Indatabuffer is not full
							IndataBuffer[Inbuffptr++] = c;	// Store recieved character in the indata buffer
						else             					// If Indata buffer is full
							Inbuffptr=0;					// Reset buffer pointer, throw all data
					}
				}
					
				
			}
		}
    }
}
